@@ -1,8 +1,11 @@
 from django.test import TestCase
 from django.core.cache import cache
 
+import urlparse
+
 
 class HttpCodeTestCase(TestCase):
+    # TODO: this should be a private method.
     def assertHttpCode(self, response, code, code_description):
         self.assertEqual(
             response.status_code, code,
@@ -15,7 +18,7 @@ class HttpCodeTestCase(TestCase):
     def assertHttpCreated(self, response):
         self.assertHttpCode(response, 201, "Created")
 
-    def assertHttpRedirect(self, response):
+    def assertHttpRedirect(self, response, location=None):
         """Assert that we had any redirect status code.
 
         """
@@ -25,9 +28,18 @@ class HttpCodeTestCase(TestCase):
             response.status_code
         )
 
+        if location:
+            if location.startswith("http://testserver/"):
+                absolute_location = location
+            else:
+                absolute_location = urlparse.urljoin("http://testserver/",  location)
+
+            self.assertEqual(response['Location'], absolute_location)
+
+
     def assertHttpBadRequest(self, response):
         self.assertHttpCode(response, 400, "Bad Request")
-        
+
     def assertHttpUnauthorized(self, response):
         self.assertHttpCode(response, 401, "Unauthorized")
 
